# {py:mod}`itkwasm.interface_types`

```{py:module} itkwasm.interface_types
```

```{autodoc2-docstring} itkwasm.interface_types
:allowtitles:
```

## Module Contents

### Classes

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`InterfaceTypes <itkwasm.interface_types.InterfaceTypes>`
  -
````

### API

`````{py:class} InterfaceTypes
:canonical: itkwasm.interface_types.InterfaceTypes

Bases: {py:obj}`enum.Enum`

````{py:attribute} TextFile
:canonical: itkwasm.interface_types.InterfaceTypes.TextFile
:value: >
   'InterfaceTextFile'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.TextFile
```

````

````{py:attribute} BinaryFile
:canonical: itkwasm.interface_types.InterfaceTypes.BinaryFile
:value: >
   'InterfaceBinaryFile'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.BinaryFile
```

````

````{py:attribute} TextStream
:canonical: itkwasm.interface_types.InterfaceTypes.TextStream
:value: >
   'InterfaceTextStream'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.TextStream
```

````

````{py:attribute} BinaryStream
:canonical: itkwasm.interface_types.InterfaceTypes.BinaryStream
:value: >
   'InterfaceBinaryStream'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.BinaryStream
```

````

````{py:attribute} Image
:canonical: itkwasm.interface_types.InterfaceTypes.Image
:value: >
   'InterfaceImage'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.Image
```

````

````{py:attribute} Mesh
:canonical: itkwasm.interface_types.InterfaceTypes.Mesh
:value: >
   'InterfaceMesh'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.Mesh
```

````

````{py:attribute} PolyData
:canonical: itkwasm.interface_types.InterfaceTypes.PolyData
:value: >
   'InterfacePolyData'

```{autodoc2-docstring} itkwasm.interface_types.InterfaceTypes.PolyData
```

````

`````
